@@ -1,34 +1,22 @@
 #
-# Copyright CEA/DAM/DIF (2009-2016)
-#  Contributor: Stephane THIELL <sthiell@stanford.edu>
+# Copyright (C) 2009-2016 CEA/DAM
+# Copyright (C) 2016 Stephane Thiell <sthiell@stanford.edu>
 #
-# This file is part of the ClusterShell library.
+# This file is part of ClusterShell.
 #
-# This software is governed by the CeCILL-C license under French law and
-# abiding by the rules of distribution of free software.  You can  use,
-# modify and/ or redistribute the software under the terms of the CeCILL-C
-# license as circulated by CEA, CNRS and INRIA at the following URL
-# "http://www.cecill.info".
+# ClusterShell is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
 #
-# As a counterpart to the access to the source code and  rights to copy,
-# modify and redistribute granted by the license, users are provided only
-# with a limited warranty  and the software's author,  the holder of the
-# economic rights,  and the successive licensors  have only  limited
-# liability.
+# ClusterShell is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
 #
-# In this respect, the user's attention is drawn to the risks associated
-# with loading,  using,  modifying and/or developing or reproducing the
-# software by the user in light of its specific status of free software,
-# that may mean  that it is complicated to manipulate,  and  that  also
-# therefore means  that it is reserved for developers  and  experienced
-# professionals having in-depth computer knowledge. Users are therefore
-# encouraged to load and test the software's suitability as regards their
-# requirements in conditions enabling the security of their systems and/or
-# data to be ensured and,  more generally, to use and operate it in the
-# same conditions as regards security.
-#
-# The fact that you are presently reading this means that you have had
-# knowledge of the CeCILL-C license and that you accept its terms.
+# You should have received a copy of the GNU Lesser General Public
+# License along with ClusterShell; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 """
 EngineClient
@@ -241,6 +229,12 @@ class EngineClient(EngineBaseTimer):
         # streams associated with this client
         self.streams = EngineClientStreamDict()
 
+    def __repr__(self):
+        # added repr(self.key)
+        return '<%s.%s instance at 0x%x key %r>' % (self.__module__,
+                                                    self.__class__.__name__,
+                                                    id(self), self.key)
+
     def _fire(self):
         """
         Fire timeout timer.
@@ -330,7 +324,7 @@ class EngineClient(EngineBaseTimer):
                     return
                 if exc.errno == errno.EPIPE:
                     # broken pipe: log warning message and do NOT retry
-                    LOGGER.warning('%s: %s', self, exc)
+                    LOGGER.warning('%r: %s', self, exc)
                     return
                 raise
             if wcnt > 0:
@@ -412,6 +406,11 @@ class EngineClient(EngineBaseTimer):
 
     def _set_write_eof(self, sname):
         """Set EOF on specific writable stream."""
+        if sname not in self.streams:
+            LOGGER.debug("stream %s was already closed on client %s, skipping",
+                         sname, self.key)
+            return
+
         wfile = self.streams[sname]
         wfile.eof = True
         if self._engine and wfile.fd and not wfile.wbuf:
