@@ -1,34 +1,23 @@
 #
-# Copyright CEA/DAM/DIF (2011-2016)
-#  Contributor: Stephane THIELL <sthiell@stanford.edu>
+# Copyright (C) 2011-2016 CEA/DAM
+# Copyright (C) 2015-2016 Stephane Thiell <sthiell@stanford.edu>
 #
+# This file is part of ClusterShell.
+#
+# ClusterShell is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# ClusterShell is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with ClusterShell; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 # This file is part of the ClusterShell library.
-#
-# This software is governed by the CeCILL-C license under French law and
-# abiding by the rules of distribution of free software.  You can  use,
-# modify and/ or redistribute the software under the terms of the CeCILL-C
-# license as circulated by CEA, CNRS and INRIA at the following URL
-# "http://www.cecill.info".
-#
-# As a counterpart to the access to the source code and  rights to copy,
-# modify and redistribute granted by the license, users are provided only
-# with a limited warranty  and the software's author,  the holder of the
-# economic rights,  and the successive licensors  have only  limited
-# liability.
-#
-# In this respect, the user's attention is drawn to the risks associated
-# with loading,  using,  modifying and/or developing or reproducing the
-# software by the user in light of its specific status of free software,
-# that may mean  that it is complicated to manipulate,  and  that  also
-# therefore means  that it is reserved for developers  and  experienced
-# professionals having in-depth computer knowledge. Users are therefore
-# encouraged to load and test the software's suitability as regards their
-# requirements in conditions enabling the security of their systems and/or
-# data to be ensured and,  more generally, to use and operate it in the
-# same conditions as regards security.
-#
-# The fact that you are presently reading this means that you have had
-# knowledge of the CeCILL-C license and that you accept its terms.
 
 """
 ClusterShell v2 tree propagation worker
@@ -313,11 +302,12 @@ class WorkerTree(DistantWorker):
                 tar.add(self.source, arcname=arcname)
                 tar.close()
                 tmptar.flush()
-                # read generated tar file and send to worker
+                # read generated tar file
                 tmptar.seek(0)
                 rbuf = tmptar.read(32768)
+                # send tar data to remote targets only
                 while len(rbuf) > 0:
-                    self.write(rbuf)
+                    self._write_remote(rbuf)
                     rbuf = tmptar.read(32768)
             except OSError, exc:
                 raise WorkerError(exc)
@@ -479,6 +469,13 @@ class WorkerTree(DistantWorker):
                 self.task._pchannel_release(gateway, self)
                 del self.gwtargets[gateway]
 
+    def _write_remote(self, buf):
+        """Write buf to remote clients only."""
+        for gateway, targets in self.gwtargets.items():
+            assert len(targets) > 0
+            self.task._pchannel(gateway, self).write(nodes=targets, buf=buf,
+                                                     worker=self)
+
     def write(self, buf):
         """Write to worker clients."""
         osexc = None
@@ -489,11 +486,8 @@ class WorkerTree(DistantWorker):
             except OSError, exc:
                 osexc = exc
 
-        for gateway, targets in self.gwtargets.items():
-            assert len(targets) > 0
-            self.task._pchannel(gateway, self).write(nodes=targets,
-                                                     buf=buf,
-                                                     worker=self)
+        self._write_remote(buf)
+
         if osexc:
             raise osexc
 
